# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mir_entities.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ymir_proto.gen import mir_common_pb2 as mir__common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mir_entities.proto',
  package='ymir.entities',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12mir_entities.proto\x12\rymir.entities\x1a\x10mir_common.proto\"\xa5\x01\n\x0cMirMetadatas\x12?\n\nattributes\x18\x01 \x03(\x0b\x32+.ymir.entities.MirMetadatas.AttributesEntry\x1aT\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.ymir.entities.MetadataAttributes:\x02\x38\x01\"\xe2\x01\n\x12MetadataAttributes\x12\x14\n\x0c\x64\x61taset_name\x18\x01 \x01(\t\x12+\n\ttimestamp\x18\x02 \x01(\x0b\x32\x18.ymir.entities.Timestamp\x12&\n\x08tvt_type\x18\x03 \x01(\x0e\x32\x14.ymir.common.TvtType\x12*\n\nasset_type\x18\x04 \x01(\x0e\x32\x16.ymir.common.AssetType\x12\r\n\x05width\x18\x05 \x01(\x05\x12\x0e\n\x06height\x18\x06 \x01(\x05\x12\x16\n\x0eimage_channels\x18\x07 \x01(\x05\",\n\tTimestamp\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x10\n\x08\x64uration\x18\x02 \x01(\x02\"\xd2\x01\n\x0eMirAnnotations\x12L\n\x10task_annotations\x18\x01 \x03(\x0b\x32\x32.ymir.entities.MirAnnotations.TaskAnnotationsEntry\x12\x14\n\x0chead_task_id\x18\x02 \x01(\t\x1a\\\n\x14TaskAnnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.ymir.entities.SingleTaskAnnotations:\x02\x38\x01\"\xce\x01\n\x15SingleTaskAnnotations\x12U\n\x11image_annotations\x18\x01 \x03(\x0b\x32:.ymir.entities.SingleTaskAnnotations.ImageAnnotationsEntry\x1a^\n\x15ImageAnnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.ymir.entities.SingleImageAnnotations:\x02\x38\x01\"H\n\x16SingleImageAnnotations\x12.\n\x0b\x61nnotations\x18\x02 \x03(\x0b\x32\x19.ymir.entities.Annotation\"^\n\nAnnotation\x12\r\n\x05index\x18\x01 \x01(\x05\x12 \n\x03\x62ox\x18\x02 \x01(\x0b\x32\x13.ymir.entities.Rect\x12\x10\n\x08\x63lass_id\x18\x03 \x01(\x05\x12\r\n\x05score\x18\x04 \x01(\x01\"2\n\x04Rect\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x12\t\n\x01w\x18\x03 \x01(\x05\x12\t\n\x01h\x18\x04 \x01(\x05\"\xaa\x05\n\x0bMirKeywords\x12:\n\x08keywords\x18\x01 \x03(\x0b\x32(.ymir.entities.MirKeywords.KeywordsEntry\x12R\n\x15predifined_keyids_cnt\x18\x02 \x03(\x0b\x32\x33.ymir.entities.MirKeywords.PredifinedKeyidsCntEntry\x12\x1f\n\x17predifined_keyids_total\x18\x03 \x01(\x05\x12V\n\x17\x63ustomized_keywords_cnt\x18\x04 \x03(\x0b\x32\x35.ymir.entities.MirKeywords.CustomizedKeywordsCntEntry\x12!\n\x19\x63ustomized_keywords_total\x18\x05 \x01(\x05\x12V\n\x17index_predifined_keyids\x18\x06 \x03(\x0b\x32\x35.ymir.entities.MirKeywords.IndexPredifinedKeyidsEntry\x1aH\n\rKeywordsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.ymir.entities.Keywords:\x02\x38\x01\x1a:\n\x18PredifinedKeyidsCntEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a<\n\x1a\x43ustomizedKeywordsCntEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1aS\n\x1aIndexPredifinedKeyidsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.ymir.entities.Assets:\x02\x38\x01\"\x1b\n\x06\x41ssets\x12\x11\n\tasset_ids\x18\x01 \x03(\t\"B\n\x08Keywords\x12\x19\n\x11predifined_keyids\x18\x01 \x03(\x05\x12\x1b\n\x13\x63ustomized_keywords\x18\x02 \x03(\t\"\x96\x01\n\x08MirTasks\x12\x31\n\x05tasks\x18\x01 \x03(\x0b\x32\".ymir.entities.MirTasks.TasksEntry\x12\x14\n\x0chead_task_id\x18\x02 \x01(\t\x1a\x41\n\nTasksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.ymir.entities.Task:\x02\x38\x01\"\xc4\x01\n\x04Task\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.ymir.common.TaskType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07task_id\x18\x03 \x01(\t\x12\x14\n\x0c\x62\x61se_task_id\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\x12\'\n\x05model\x18\x06 \x01(\x0b\x32\x18.ymir.entities.ModelMeta\x12\x0c\n\x04\x61rgs\x18\x64 \x01(\t\x12\x18\n\x10\x61ncestor_task_id\x18\x65 \x01(\t\"P\n\tModelMeta\x12\x12\n\nmodel_hash\x18\x01 \x01(\t\x12\x1e\n\x16mean_average_precision\x18\x02 \x01(\x02\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\tb\x06proto3'
  ,
  dependencies=[mir__common__pb2.DESCRIPTOR,])




_MIRMETADATAS_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='ymir.entities.MirMetadatas.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ymir.entities.MirMetadatas.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ymir.entities.MirMetadatas.AttributesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=221,
)

_MIRMETADATAS = _descriptor.Descriptor(
  name='MirMetadatas',
  full_name='ymir.entities.MirMetadatas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='ymir.entities.MirMetadatas.attributes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MIRMETADATAS_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=221,
)


_METADATAATTRIBUTES = _descriptor.Descriptor(
  name='MetadataAttributes',
  full_name='ymir.entities.MetadataAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_name', full_name='ymir.entities.MetadataAttributes.dataset_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ymir.entities.MetadataAttributes.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tvt_type', full_name='ymir.entities.MetadataAttributes.tvt_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asset_type', full_name='ymir.entities.MetadataAttributes.asset_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='ymir.entities.MetadataAttributes.width', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='ymir.entities.MetadataAttributes.height', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_channels', full_name='ymir.entities.MetadataAttributes.image_channels', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=450,
)


_TIMESTAMP = _descriptor.Descriptor(
  name='Timestamp',
  full_name='ymir.entities.Timestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='ymir.entities.Timestamp.start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='ymir.entities.Timestamp.duration', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=452,
  serialized_end=496,
)


_MIRANNOTATIONS_TASKANNOTATIONSENTRY = _descriptor.Descriptor(
  name='TaskAnnotationsEntry',
  full_name='ymir.entities.MirAnnotations.TaskAnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ymir.entities.MirAnnotations.TaskAnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ymir.entities.MirAnnotations.TaskAnnotationsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=709,
)

_MIRANNOTATIONS = _descriptor.Descriptor(
  name='MirAnnotations',
  full_name='ymir.entities.MirAnnotations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_annotations', full_name='ymir.entities.MirAnnotations.task_annotations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='head_task_id', full_name='ymir.entities.MirAnnotations.head_task_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MIRANNOTATIONS_TASKANNOTATIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=709,
)


_SINGLETASKANNOTATIONS_IMAGEANNOTATIONSENTRY = _descriptor.Descriptor(
  name='ImageAnnotationsEntry',
  full_name='ymir.entities.SingleTaskAnnotations.ImageAnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ymir.entities.SingleTaskAnnotations.ImageAnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ymir.entities.SingleTaskAnnotations.ImageAnnotationsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=824,
  serialized_end=918,
)

_SINGLETASKANNOTATIONS = _descriptor.Descriptor(
  name='SingleTaskAnnotations',
  full_name='ymir.entities.SingleTaskAnnotations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_annotations', full_name='ymir.entities.SingleTaskAnnotations.image_annotations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SINGLETASKANNOTATIONS_IMAGEANNOTATIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=918,
)


_SINGLEIMAGEANNOTATIONS = _descriptor.Descriptor(
  name='SingleImageAnnotations',
  full_name='ymir.entities.SingleImageAnnotations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='annotations', full_name='ymir.entities.SingleImageAnnotations.annotations', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=920,
  serialized_end=992,
)


_ANNOTATION = _descriptor.Descriptor(
  name='Annotation',
  full_name='ymir.entities.Annotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='ymir.entities.Annotation.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box', full_name='ymir.entities.Annotation.box', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_id', full_name='ymir.entities.Annotation.class_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='ymir.entities.Annotation.score', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1088,
)


_RECT = _descriptor.Descriptor(
  name='Rect',
  full_name='ymir.entities.Rect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='ymir.entities.Rect.x', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='ymir.entities.Rect.y', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='w', full_name='ymir.entities.Rect.w', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='h', full_name='ymir.entities.Rect.h', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1090,
  serialized_end=1140,
)


_MIRKEYWORDS_KEYWORDSENTRY = _descriptor.Descriptor(
  name='KeywordsEntry',
  full_name='ymir.entities.MirKeywords.KeywordsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ymir.entities.MirKeywords.KeywordsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ymir.entities.MirKeywords.KeywordsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1546,
  serialized_end=1618,
)

_MIRKEYWORDS_PREDIFINEDKEYIDSCNTENTRY = _descriptor.Descriptor(
  name='PredifinedKeyidsCntEntry',
  full_name='ymir.entities.MirKeywords.PredifinedKeyidsCntEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ymir.entities.MirKeywords.PredifinedKeyidsCntEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ymir.entities.MirKeywords.PredifinedKeyidsCntEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1620,
  serialized_end=1678,
)

_MIRKEYWORDS_CUSTOMIZEDKEYWORDSCNTENTRY = _descriptor.Descriptor(
  name='CustomizedKeywordsCntEntry',
  full_name='ymir.entities.MirKeywords.CustomizedKeywordsCntEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ymir.entities.MirKeywords.CustomizedKeywordsCntEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ymir.entities.MirKeywords.CustomizedKeywordsCntEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1680,
  serialized_end=1740,
)

_MIRKEYWORDS_INDEXPREDIFINEDKEYIDSENTRY = _descriptor.Descriptor(
  name='IndexPredifinedKeyidsEntry',
  full_name='ymir.entities.MirKeywords.IndexPredifinedKeyidsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ymir.entities.MirKeywords.IndexPredifinedKeyidsEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ymir.entities.MirKeywords.IndexPredifinedKeyidsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1742,
  serialized_end=1825,
)

_MIRKEYWORDS = _descriptor.Descriptor(
  name='MirKeywords',
  full_name='ymir.entities.MirKeywords',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keywords', full_name='ymir.entities.MirKeywords.keywords', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predifined_keyids_cnt', full_name='ymir.entities.MirKeywords.predifined_keyids_cnt', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predifined_keyids_total', full_name='ymir.entities.MirKeywords.predifined_keyids_total', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customized_keywords_cnt', full_name='ymir.entities.MirKeywords.customized_keywords_cnt', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customized_keywords_total', full_name='ymir.entities.MirKeywords.customized_keywords_total', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index_predifined_keyids', full_name='ymir.entities.MirKeywords.index_predifined_keyids', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MIRKEYWORDS_KEYWORDSENTRY, _MIRKEYWORDS_PREDIFINEDKEYIDSCNTENTRY, _MIRKEYWORDS_CUSTOMIZEDKEYWORDSCNTENTRY, _MIRKEYWORDS_INDEXPREDIFINEDKEYIDSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1143,
  serialized_end=1825,
)


_ASSETS = _descriptor.Descriptor(
  name='Assets',
  full_name='ymir.entities.Assets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_ids', full_name='ymir.entities.Assets.asset_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1827,
  serialized_end=1854,
)


_KEYWORDS = _descriptor.Descriptor(
  name='Keywords',
  full_name='ymir.entities.Keywords',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='predifined_keyids', full_name='ymir.entities.Keywords.predifined_keyids', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customized_keywords', full_name='ymir.entities.Keywords.customized_keywords', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1856,
  serialized_end=1922,
)


_MIRTASKS_TASKSENTRY = _descriptor.Descriptor(
  name='TasksEntry',
  full_name='ymir.entities.MirTasks.TasksEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ymir.entities.MirTasks.TasksEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ymir.entities.MirTasks.TasksEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2010,
  serialized_end=2075,
)

_MIRTASKS = _descriptor.Descriptor(
  name='MirTasks',
  full_name='ymir.entities.MirTasks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tasks', full_name='ymir.entities.MirTasks.tasks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='head_task_id', full_name='ymir.entities.MirTasks.head_task_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MIRTASKS_TASKSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1925,
  serialized_end=2075,
)


_TASK = _descriptor.Descriptor(
  name='Task',
  full_name='ymir.entities.Task',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='ymir.entities.Task.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ymir.entities.Task.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ymir.entities.Task.task_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_task_id', full_name='ymir.entities.Task.base_task_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ymir.entities.Task.timestamp', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='ymir.entities.Task.model', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='ymir.entities.Task.args', index=6,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ancestor_task_id', full_name='ymir.entities.Task.ancestor_task_id', index=7,
      number=101, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2078,
  serialized_end=2274,
)


_MODELMETA = _descriptor.Descriptor(
  name='ModelMeta',
  full_name='ymir.entities.ModelMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_hash', full_name='ymir.entities.ModelMeta.model_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_average_precision', full_name='ymir.entities.ModelMeta.mean_average_precision', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context', full_name='ymir.entities.ModelMeta.context', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2276,
  serialized_end=2356,
)

_MIRMETADATAS_ATTRIBUTESENTRY.fields_by_name['value'].message_type = _METADATAATTRIBUTES
_MIRMETADATAS_ATTRIBUTESENTRY.containing_type = _MIRMETADATAS
_MIRMETADATAS.fields_by_name['attributes'].message_type = _MIRMETADATAS_ATTRIBUTESENTRY
_METADATAATTRIBUTES.fields_by_name['timestamp'].message_type = _TIMESTAMP
_METADATAATTRIBUTES.fields_by_name['tvt_type'].enum_type = mir__common__pb2._TVTTYPE
_METADATAATTRIBUTES.fields_by_name['asset_type'].enum_type = mir__common__pb2._ASSETTYPE
_MIRANNOTATIONS_TASKANNOTATIONSENTRY.fields_by_name['value'].message_type = _SINGLETASKANNOTATIONS
_MIRANNOTATIONS_TASKANNOTATIONSENTRY.containing_type = _MIRANNOTATIONS
_MIRANNOTATIONS.fields_by_name['task_annotations'].message_type = _MIRANNOTATIONS_TASKANNOTATIONSENTRY
_SINGLETASKANNOTATIONS_IMAGEANNOTATIONSENTRY.fields_by_name['value'].message_type = _SINGLEIMAGEANNOTATIONS
_SINGLETASKANNOTATIONS_IMAGEANNOTATIONSENTRY.containing_type = _SINGLETASKANNOTATIONS
_SINGLETASKANNOTATIONS.fields_by_name['image_annotations'].message_type = _SINGLETASKANNOTATIONS_IMAGEANNOTATIONSENTRY
_SINGLEIMAGEANNOTATIONS.fields_by_name['annotations'].message_type = _ANNOTATION
_ANNOTATION.fields_by_name['box'].message_type = _RECT
_MIRKEYWORDS_KEYWORDSENTRY.fields_by_name['value'].message_type = _KEYWORDS
_MIRKEYWORDS_KEYWORDSENTRY.containing_type = _MIRKEYWORDS
_MIRKEYWORDS_PREDIFINEDKEYIDSCNTENTRY.containing_type = _MIRKEYWORDS
_MIRKEYWORDS_CUSTOMIZEDKEYWORDSCNTENTRY.containing_type = _MIRKEYWORDS
_MIRKEYWORDS_INDEXPREDIFINEDKEYIDSENTRY.fields_by_name['value'].message_type = _ASSETS
_MIRKEYWORDS_INDEXPREDIFINEDKEYIDSENTRY.containing_type = _MIRKEYWORDS
_MIRKEYWORDS.fields_by_name['keywords'].message_type = _MIRKEYWORDS_KEYWORDSENTRY
_MIRKEYWORDS.fields_by_name['predifined_keyids_cnt'].message_type = _MIRKEYWORDS_PREDIFINEDKEYIDSCNTENTRY
_MIRKEYWORDS.fields_by_name['customized_keywords_cnt'].message_type = _MIRKEYWORDS_CUSTOMIZEDKEYWORDSCNTENTRY
_MIRKEYWORDS.fields_by_name['index_predifined_keyids'].message_type = _MIRKEYWORDS_INDEXPREDIFINEDKEYIDSENTRY
_MIRTASKS_TASKSENTRY.fields_by_name['value'].message_type = _TASK
_MIRTASKS_TASKSENTRY.containing_type = _MIRTASKS
_MIRTASKS.fields_by_name['tasks'].message_type = _MIRTASKS_TASKSENTRY
_TASK.fields_by_name['type'].enum_type = mir__common__pb2._TASKTYPE
_TASK.fields_by_name['model'].message_type = _MODELMETA
DESCRIPTOR.message_types_by_name['MirMetadatas'] = _MIRMETADATAS
DESCRIPTOR.message_types_by_name['MetadataAttributes'] = _METADATAATTRIBUTES
DESCRIPTOR.message_types_by_name['Timestamp'] = _TIMESTAMP
DESCRIPTOR.message_types_by_name['MirAnnotations'] = _MIRANNOTATIONS
DESCRIPTOR.message_types_by_name['SingleTaskAnnotations'] = _SINGLETASKANNOTATIONS
DESCRIPTOR.message_types_by_name['SingleImageAnnotations'] = _SINGLEIMAGEANNOTATIONS
DESCRIPTOR.message_types_by_name['Annotation'] = _ANNOTATION
DESCRIPTOR.message_types_by_name['Rect'] = _RECT
DESCRIPTOR.message_types_by_name['MirKeywords'] = _MIRKEYWORDS
DESCRIPTOR.message_types_by_name['Assets'] = _ASSETS
DESCRIPTOR.message_types_by_name['Keywords'] = _KEYWORDS
DESCRIPTOR.message_types_by_name['MirTasks'] = _MIRTASKS
DESCRIPTOR.message_types_by_name['Task'] = _TASK
DESCRIPTOR.message_types_by_name['ModelMeta'] = _MODELMETA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MirMetadatas = _reflection.GeneratedProtocolMessageType('MirMetadatas', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MIRMETADATAS_ATTRIBUTESENTRY,
    '__module__' : 'mir_entities_pb2'
    # @@protoc_insertion_point(class_scope:ymir.entities.MirMetadatas.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _MIRMETADATAS,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.MirMetadatas)
  })
_sym_db.RegisterMessage(MirMetadatas)
_sym_db.RegisterMessage(MirMetadatas.AttributesEntry)

MetadataAttributes = _reflection.GeneratedProtocolMessageType('MetadataAttributes', (_message.Message,), {
  'DESCRIPTOR' : _METADATAATTRIBUTES,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.MetadataAttributes)
  })
_sym_db.RegisterMessage(MetadataAttributes)

Timestamp = _reflection.GeneratedProtocolMessageType('Timestamp', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMP,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.Timestamp)
  })
_sym_db.RegisterMessage(Timestamp)

MirAnnotations = _reflection.GeneratedProtocolMessageType('MirAnnotations', (_message.Message,), {

  'TaskAnnotationsEntry' : _reflection.GeneratedProtocolMessageType('TaskAnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MIRANNOTATIONS_TASKANNOTATIONSENTRY,
    '__module__' : 'mir_entities_pb2'
    # @@protoc_insertion_point(class_scope:ymir.entities.MirAnnotations.TaskAnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _MIRANNOTATIONS,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.MirAnnotations)
  })
_sym_db.RegisterMessage(MirAnnotations)
_sym_db.RegisterMessage(MirAnnotations.TaskAnnotationsEntry)

SingleTaskAnnotations = _reflection.GeneratedProtocolMessageType('SingleTaskAnnotations', (_message.Message,), {

  'ImageAnnotationsEntry' : _reflection.GeneratedProtocolMessageType('ImageAnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SINGLETASKANNOTATIONS_IMAGEANNOTATIONSENTRY,
    '__module__' : 'mir_entities_pb2'
    # @@protoc_insertion_point(class_scope:ymir.entities.SingleTaskAnnotations.ImageAnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _SINGLETASKANNOTATIONS,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.SingleTaskAnnotations)
  })
_sym_db.RegisterMessage(SingleTaskAnnotations)
_sym_db.RegisterMessage(SingleTaskAnnotations.ImageAnnotationsEntry)

SingleImageAnnotations = _reflection.GeneratedProtocolMessageType('SingleImageAnnotations', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEIMAGEANNOTATIONS,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.SingleImageAnnotations)
  })
_sym_db.RegisterMessage(SingleImageAnnotations)

Annotation = _reflection.GeneratedProtocolMessageType('Annotation', (_message.Message,), {
  'DESCRIPTOR' : _ANNOTATION,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.Annotation)
  })
_sym_db.RegisterMessage(Annotation)

Rect = _reflection.GeneratedProtocolMessageType('Rect', (_message.Message,), {
  'DESCRIPTOR' : _RECT,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.Rect)
  })
_sym_db.RegisterMessage(Rect)

MirKeywords = _reflection.GeneratedProtocolMessageType('MirKeywords', (_message.Message,), {

  'KeywordsEntry' : _reflection.GeneratedProtocolMessageType('KeywordsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MIRKEYWORDS_KEYWORDSENTRY,
    '__module__' : 'mir_entities_pb2'
    # @@protoc_insertion_point(class_scope:ymir.entities.MirKeywords.KeywordsEntry)
    })
  ,

  'PredifinedKeyidsCntEntry' : _reflection.GeneratedProtocolMessageType('PredifinedKeyidsCntEntry', (_message.Message,), {
    'DESCRIPTOR' : _MIRKEYWORDS_PREDIFINEDKEYIDSCNTENTRY,
    '__module__' : 'mir_entities_pb2'
    # @@protoc_insertion_point(class_scope:ymir.entities.MirKeywords.PredifinedKeyidsCntEntry)
    })
  ,

  'CustomizedKeywordsCntEntry' : _reflection.GeneratedProtocolMessageType('CustomizedKeywordsCntEntry', (_message.Message,), {
    'DESCRIPTOR' : _MIRKEYWORDS_CUSTOMIZEDKEYWORDSCNTENTRY,
    '__module__' : 'mir_entities_pb2'
    # @@protoc_insertion_point(class_scope:ymir.entities.MirKeywords.CustomizedKeywordsCntEntry)
    })
  ,

  'IndexPredifinedKeyidsEntry' : _reflection.GeneratedProtocolMessageType('IndexPredifinedKeyidsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MIRKEYWORDS_INDEXPREDIFINEDKEYIDSENTRY,
    '__module__' : 'mir_entities_pb2'
    # @@protoc_insertion_point(class_scope:ymir.entities.MirKeywords.IndexPredifinedKeyidsEntry)
    })
  ,
  'DESCRIPTOR' : _MIRKEYWORDS,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.MirKeywords)
  })
_sym_db.RegisterMessage(MirKeywords)
_sym_db.RegisterMessage(MirKeywords.KeywordsEntry)
_sym_db.RegisterMessage(MirKeywords.PredifinedKeyidsCntEntry)
_sym_db.RegisterMessage(MirKeywords.CustomizedKeywordsCntEntry)
_sym_db.RegisterMessage(MirKeywords.IndexPredifinedKeyidsEntry)

Assets = _reflection.GeneratedProtocolMessageType('Assets', (_message.Message,), {
  'DESCRIPTOR' : _ASSETS,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.Assets)
  })
_sym_db.RegisterMessage(Assets)

Keywords = _reflection.GeneratedProtocolMessageType('Keywords', (_message.Message,), {
  'DESCRIPTOR' : _KEYWORDS,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.Keywords)
  })
_sym_db.RegisterMessage(Keywords)

MirTasks = _reflection.GeneratedProtocolMessageType('MirTasks', (_message.Message,), {

  'TasksEntry' : _reflection.GeneratedProtocolMessageType('TasksEntry', (_message.Message,), {
    'DESCRIPTOR' : _MIRTASKS_TASKSENTRY,
    '__module__' : 'mir_entities_pb2'
    # @@protoc_insertion_point(class_scope:ymir.entities.MirTasks.TasksEntry)
    })
  ,
  'DESCRIPTOR' : _MIRTASKS,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.MirTasks)
  })
_sym_db.RegisterMessage(MirTasks)
_sym_db.RegisterMessage(MirTasks.TasksEntry)

Task = _reflection.GeneratedProtocolMessageType('Task', (_message.Message,), {
  'DESCRIPTOR' : _TASK,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.Task)
  })
_sym_db.RegisterMessage(Task)

ModelMeta = _reflection.GeneratedProtocolMessageType('ModelMeta', (_message.Message,), {
  'DESCRIPTOR' : _MODELMETA,
  '__module__' : 'mir_entities_pb2'
  # @@protoc_insertion_point(class_scope:ymir.entities.ModelMeta)
  })
_sym_db.RegisterMessage(ModelMeta)


_MIRMETADATAS_ATTRIBUTESENTRY._options = None
_MIRANNOTATIONS_TASKANNOTATIONSENTRY._options = None
_SINGLETASKANNOTATIONS_IMAGEANNOTATIONSENTRY._options = None
_MIRKEYWORDS_KEYWORDSENTRY._options = None
_MIRKEYWORDS_PREDIFINEDKEYIDSCNTENTRY._options = None
_MIRKEYWORDS_CUSTOMIZEDKEYWORDSCNTENTRY._options = None
_MIRKEYWORDS_INDEXPREDIFINEDKEYIDSENTRY._options = None
_MIRTASKS_TASKSENTRY._options = None
# @@protoc_insertion_point(module_scope)
