# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mir_controller_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ymir_proto.gen import mir_common_pb2 as mir__common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mir_controller_service.proto',
  package='ymir.controller',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cmir_controller_service.proto\x12\x0fymir.controller\x1a\x10mir_common.proto\"\xa9\x03\n\nGeneralReq\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0f\n\x07repo_id\x18\x02 \x01(\t\x12.\n\x08req_type\x18\x03 \x01(\x0e\x32\x1c.ymir.controller.RequestType\x12\x0f\n\x07task_id\x18\x04 \x01(\t\x12\x14\n\x0csingleton_op\x18\x05 \x01(\t\x12\x13\n\x0bhis_task_id\x18\x06 \x01(\t\x12\x13\n\x0b\x64st_task_id\x18\x07 \x01(\t\x12\x16\n\x0ein_dataset_ids\x18\x08 \x03(\t\x12\x16\n\x0e\x65x_dataset_ids\x18\t \x03(\t\x12\x14\n\x0cin_class_ids\x18\n \x03(\x05\x12\x14\n\x0c\x65x_class_ids\x18\x0b \x03(\x05\x12\r\n\x05\x66orce\x18\x0c \x01(\x08\x12\x16\n\x0e\x63ommit_message\x18\r \x01(\t\x12\x38\n\x0freq_create_task\x18\xe9\x07 \x01(\x0b\x32\x1e.ymir.controller.ReqCreateTask\x12;\n\x11req_get_task_info\x18\xea\x07 \x01(\x0b\x32\x1f.ymir.controller.ReqGetTaskInfo\"\x92\x01\n\x0bGeneralResp\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x13\n\x0breq_task_id\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x10\n\x08\x65xt_strs\x18\x04 \x03(\t\x12=\n\x12resp_get_task_info\x18\xe8\x07 \x01(\x0b\x32 .ymir.controller.RespGetTaskInfo\"\xcf\x03\n\rReqCreateTask\x12(\n\ttask_type\x18\x01 \x01(\x0e\x32\x15.ymir.common.TaskType\x12\x15\n\rsampling_rate\x18\x02 \x01(\x02\x12\x17\n\x0fno_task_monitor\x18\x03 \x01(\x08\x12.\n\x06\x66ilter\x18\x65 \x01(\x0b\x32\x1e.ymir.controller.TaskReqFilter\x12\x32\n\x08training\x18\x66 \x01(\x0b\x32 .ymir.controller.TaskReqTraining\x12.\n\x06mining\x18g \x01(\x0b\x32\x1e.ymir.controller.TaskReqMining\x12\x34\n\timporting\x18h \x01(\x0b\x32!.ymir.controller.TaskReqImporting\x12\x34\n\texporting\x18i \x01(\x0b\x32!.ymir.controller.TaskReqExporting\x12\x34\n\tinference\x18j \x01(\x0b\x32!.ymir.controller.TaskReqInference\x12.\n\x04\x63opy\x18k \x01(\x0b\x32 .ymir.controller.TaskReqCopyData\"S\n\rTaskReqFilter\x12\x16\n\x0ein_dataset_ids\x18\x01 \x03(\t\x12\x14\n\x0cin_class_ids\x18\x02 \x03(\x05\x12\x14\n\x0c\x65x_class_ids\x18\x03 \x03(\x05\"\xce\x01\n\x0fTaskReqTraining\x12N\n\x10in_dataset_types\x18\x01 \x03(\x0b\x32\x34.ymir.controller.TaskReqTraining.TrainingDatasetType\x12\x14\n\x0cin_class_ids\x18\x02 \x03(\x05\x1aU\n\x13TrainingDatasetType\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12*\n\x0c\x64\x61taset_type\x18\x02 \x01(\x0e\x32\x14.ymir.common.TvtType\"b\n\rTaskReqMining\x12\x16\n\x0ein_dataset_ids\x18\x01 \x03(\t\x12\x16\n\x0e\x65x_dataset_ids\x18\x02 \x03(\t\x12\x12\n\nmodel_hash\x18\x03 \x01(\t\x12\r\n\x05top_k\x18\x04 \x01(\x05\"=\n\x10TaskReqImporting\x12\x11\n\tasset_dir\x18\x01 \x01(\t\x12\x16\n\x0e\x61nnotation_dir\x18\x02 \x01(\t\"{\n\x10TaskReqExporting\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12(\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x18.ymir.common.LabelFormat\x12\x11\n\tasset_dir\x18\x03 \x01(\t\x12\x16\n\x0e\x61nnotation_dir\x18\x04 \x01(\t\"\x12\n\x10TaskReqInference\"S\n\x0fTaskReqCopyData\x12\x13\n\x0bsrc_user_id\x18\x01 \x01(\t\x12\x13\n\x0bsrc_repo_id\x18\x02 \x01(\t\x12\x16\n\x0esrc_dataset_id\x18\x03 \x01(\t\"\"\n\x0eReqGetTaskInfo\x12\x10\n\x08task_ids\x18\x01 \x03(\t\"\xa7\x01\n\x0fRespGetTaskInfo\x12\x43\n\ntask_infos\x18\x01 \x03(\x0b\x32/.ymir.controller.RespGetTaskInfo.TaskInfosEntry\x1aO\n\x0eTaskInfosEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.ymir.controller.TaskInfoItem:\x02\x38\x01\"\x95\x02\n\x0cTaskInfoItem\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x61se_task_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x0f\n\x07repo_id\x18\x04 \x01(\t\x12#\n\x04type\x18\x05 \x01(\x0e\x32\x15.ymir.common.TaskType\x12%\n\x05state\x18\x06 \x01(\x0e\x32\x16.ymir.common.TaskState\x12\x17\n\x0fstart_timestamp\x18\x07 \x01(\x03\x12\x18\n\x10\x66inish_timestamp\x18\x08 \x01(\x03\x12\x18\n\x10update_timestamp\x18\t \x01(\x03\x12\x0f\n\x07percent\x18\n \x01(\x02\x12\x12\n\nlast_error\x18\x0b \x01(\t\"\xaa\x01\n\x12TaskMonitorStorage\x12=\n\x05tasks\x18\x01 \x03(\x0b\x32..ymir.controller.TaskMonitorStorage.TasksEntry\x1aU\n\nTasksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.ymir.controller.TaskMonitorStorageItem:\x02\x38\x01\"\xd9\x01\n\x16TaskMonitorStorageItem\x12\x33\n\x0cgeneral_info\x18\x01 \x01(\x0b\x32\x1d.ymir.controller.TaskInfoItem\x12\x19\n\x11monitor_file_path\x18\x02 \x01(\t\x12\x19\n\x11storage_file_path\x18\x03 \x01(\t\x12\x11\n\trepo_root\x18\x04 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x05 \x01(\t\x12,\n\x07request\x18\x64 \x01(\x0b\x32\x1b.ymir.controller.GeneralReq*\xd0\x02\n\x0bRequestType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x43MD_BRANCH_DEL\x10\x01\x12\x13\n\x0f\x43MD_BRANCH_LIST\x10\x02\x12\x17\n\x13\x43MD_BRANCH_CHECKOUT\x10\x03\x12\x15\n\x11\x43MD_BRANCH_CREATE\x10\x04\x12\r\n\tCMD_CLONE\x10\x05\x12\x0e\n\nCMD_COMMIT\x10\x06\x12\x0e\n\nCMD_FILTER\x10\x07\x12\x0c\n\x08\x43MD_INIT\x10\x08\x12\x0b\n\x07\x43MD_LOG\x10\t\x12\r\n\tCMD_MERGE\x10\n\x12\r\n\tUSER_LIST\x10\x65\x12\x0f\n\x0bUSER_CREATE\x10\x66\x12\x0f\n\x0bUSER_REMOVE\x10g\x12\r\n\tREPO_LIST\x10h\x12\x0f\n\x0bREPO_CREATE\x10i\x12\x0f\n\x0bREPO_REMOVE\x10j\x12\x10\n\x0bTASK_CREATE\x10\xe9\x07\x12\x0e\n\tTASK_INFO\x10\xea\x07\x32l\n\x16mir_controller_service\x12R\n\x13\x64\x61ta_manage_request\x12\x1b.ymir.controller.GeneralReq\x1a\x1c.ymir.controller.GeneralResp\"\x00\x62\x06proto3'
  ,
  dependencies=[mir__common__pb2.DESCRIPTOR,])

_REQUESTTYPE = _descriptor.EnumDescriptor(
  name='RequestType',
  full_name='ymir.controller.RequestType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_BRANCH_DEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_BRANCH_LIST', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_BRANCH_CHECKOUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_BRANCH_CREATE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_CLONE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_COMMIT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_FILTER', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_INIT', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_LOG', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_MERGE', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_LIST', index=11, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_CREATE', index=12, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_REMOVE', index=13, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPO_LIST', index=14, number=104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPO_CREATE', index=15, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPO_REMOVE', index=16, number=106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TASK_CREATE', index=17, number=1001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TASK_INFO', index=18, number=1002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2677,
  serialized_end=3013,
)
_sym_db.RegisterEnumDescriptor(_REQUESTTYPE)

RequestType = enum_type_wrapper.EnumTypeWrapper(_REQUESTTYPE)
UNKNOWN = 0
CMD_BRANCH_DEL = 1
CMD_BRANCH_LIST = 2
CMD_BRANCH_CHECKOUT = 3
CMD_BRANCH_CREATE = 4
CMD_CLONE = 5
CMD_COMMIT = 6
CMD_FILTER = 7
CMD_INIT = 8
CMD_LOG = 9
CMD_MERGE = 10
USER_LIST = 101
USER_CREATE = 102
USER_REMOVE = 103
REPO_LIST = 104
REPO_CREATE = 105
REPO_REMOVE = 106
TASK_CREATE = 1001
TASK_INFO = 1002



_GENERALREQ = _descriptor.Descriptor(
  name='GeneralReq',
  full_name='ymir.controller.GeneralReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='ymir.controller.GeneralReq.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repo_id', full_name='ymir.controller.GeneralReq.repo_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='req_type', full_name='ymir.controller.GeneralReq.req_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ymir.controller.GeneralReq.task_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='singleton_op', full_name='ymir.controller.GeneralReq.singleton_op', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='his_task_id', full_name='ymir.controller.GeneralReq.his_task_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_task_id', full_name='ymir.controller.GeneralReq.dst_task_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_dataset_ids', full_name='ymir.controller.GeneralReq.in_dataset_ids', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ex_dataset_ids', full_name='ymir.controller.GeneralReq.ex_dataset_ids', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_class_ids', full_name='ymir.controller.GeneralReq.in_class_ids', index=9,
      number=10, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ex_class_ids', full_name='ymir.controller.GeneralReq.ex_class_ids', index=10,
      number=11, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='ymir.controller.GeneralReq.force', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit_message', full_name='ymir.controller.GeneralReq.commit_message', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='req_create_task', full_name='ymir.controller.GeneralReq.req_create_task', index=13,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='req_get_task_info', full_name='ymir.controller.GeneralReq.req_get_task_info', index=14,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=493,
)


_GENERALRESP = _descriptor.Descriptor(
  name='GeneralResp',
  full_name='ymir.controller.GeneralResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='ymir.controller.GeneralResp.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='req_task_id', full_name='ymir.controller.GeneralResp.req_task_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='ymir.controller.GeneralResp.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ext_strs', full_name='ymir.controller.GeneralResp.ext_strs', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resp_get_task_info', full_name='ymir.controller.GeneralResp.resp_get_task_info', index=4,
      number=1000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=496,
  serialized_end=642,
)


_REQCREATETASK = _descriptor.Descriptor(
  name='ReqCreateTask',
  full_name='ymir.controller.ReqCreateTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_type', full_name='ymir.controller.ReqCreateTask.task_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling_rate', full_name='ymir.controller.ReqCreateTask.sampling_rate', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_task_monitor', full_name='ymir.controller.ReqCreateTask.no_task_monitor', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='ymir.controller.ReqCreateTask.filter', index=3,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='training', full_name='ymir.controller.ReqCreateTask.training', index=4,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mining', full_name='ymir.controller.ReqCreateTask.mining', index=5,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='importing', full_name='ymir.controller.ReqCreateTask.importing', index=6,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exporting', full_name='ymir.controller.ReqCreateTask.exporting', index=7,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inference', full_name='ymir.controller.ReqCreateTask.inference', index=8,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='copy', full_name='ymir.controller.ReqCreateTask.copy', index=9,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=645,
  serialized_end=1108,
)


_TASKREQFILTER = _descriptor.Descriptor(
  name='TaskReqFilter',
  full_name='ymir.controller.TaskReqFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='in_dataset_ids', full_name='ymir.controller.TaskReqFilter.in_dataset_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_class_ids', full_name='ymir.controller.TaskReqFilter.in_class_ids', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ex_class_ids', full_name='ymir.controller.TaskReqFilter.ex_class_ids', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1193,
)


_TASKREQTRAINING_TRAININGDATASETTYPE = _descriptor.Descriptor(
  name='TrainingDatasetType',
  full_name='ymir.controller.TaskReqTraining.TrainingDatasetType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='ymir.controller.TaskReqTraining.TrainingDatasetType.dataset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset_type', full_name='ymir.controller.TaskReqTraining.TrainingDatasetType.dataset_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1317,
  serialized_end=1402,
)

_TASKREQTRAINING = _descriptor.Descriptor(
  name='TaskReqTraining',
  full_name='ymir.controller.TaskReqTraining',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='in_dataset_types', full_name='ymir.controller.TaskReqTraining.in_dataset_types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_class_ids', full_name='ymir.controller.TaskReqTraining.in_class_ids', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TASKREQTRAINING_TRAININGDATASETTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1196,
  serialized_end=1402,
)


_TASKREQMINING = _descriptor.Descriptor(
  name='TaskReqMining',
  full_name='ymir.controller.TaskReqMining',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='in_dataset_ids', full_name='ymir.controller.TaskReqMining.in_dataset_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ex_dataset_ids', full_name='ymir.controller.TaskReqMining.ex_dataset_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_hash', full_name='ymir.controller.TaskReqMining.model_hash', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='top_k', full_name='ymir.controller.TaskReqMining.top_k', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1404,
  serialized_end=1502,
)


_TASKREQIMPORTING = _descriptor.Descriptor(
  name='TaskReqImporting',
  full_name='ymir.controller.TaskReqImporting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_dir', full_name='ymir.controller.TaskReqImporting.asset_dir', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotation_dir', full_name='ymir.controller.TaskReqImporting.annotation_dir', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1504,
  serialized_end=1565,
)


_TASKREQEXPORTING = _descriptor.Descriptor(
  name='TaskReqExporting',
  full_name='ymir.controller.TaskReqExporting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='ymir.controller.TaskReqExporting.dataset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='ymir.controller.TaskReqExporting.format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asset_dir', full_name='ymir.controller.TaskReqExporting.asset_dir', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotation_dir', full_name='ymir.controller.TaskReqExporting.annotation_dir', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1690,
)


_TASKREQINFERENCE = _descriptor.Descriptor(
  name='TaskReqInference',
  full_name='ymir.controller.TaskReqInference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1692,
  serialized_end=1710,
)


_TASKREQCOPYDATA = _descriptor.Descriptor(
  name='TaskReqCopyData',
  full_name='ymir.controller.TaskReqCopyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_user_id', full_name='ymir.controller.TaskReqCopyData.src_user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src_repo_id', full_name='ymir.controller.TaskReqCopyData.src_repo_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src_dataset_id', full_name='ymir.controller.TaskReqCopyData.src_dataset_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1712,
  serialized_end=1795,
)


_REQGETTASKINFO = _descriptor.Descriptor(
  name='ReqGetTaskInfo',
  full_name='ymir.controller.ReqGetTaskInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_ids', full_name='ymir.controller.ReqGetTaskInfo.task_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1797,
  serialized_end=1831,
)


_RESPGETTASKINFO_TASKINFOSENTRY = _descriptor.Descriptor(
  name='TaskInfosEntry',
  full_name='ymir.controller.RespGetTaskInfo.TaskInfosEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ymir.controller.RespGetTaskInfo.TaskInfosEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ymir.controller.RespGetTaskInfo.TaskInfosEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1922,
  serialized_end=2001,
)

_RESPGETTASKINFO = _descriptor.Descriptor(
  name='RespGetTaskInfo',
  full_name='ymir.controller.RespGetTaskInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_infos', full_name='ymir.controller.RespGetTaskInfo.task_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESPGETTASKINFO_TASKINFOSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1834,
  serialized_end=2001,
)


_TASKINFOITEM = _descriptor.Descriptor(
  name='TaskInfoItem',
  full_name='ymir.controller.TaskInfoItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ymir.controller.TaskInfoItem.task_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_task_id', full_name='ymir.controller.TaskInfoItem.base_task_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='ymir.controller.TaskInfoItem.user_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repo_id', full_name='ymir.controller.TaskInfoItem.repo_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='ymir.controller.TaskInfoItem.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='ymir.controller.TaskInfoItem.state', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='ymir.controller.TaskInfoItem.start_timestamp', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finish_timestamp', full_name='ymir.controller.TaskInfoItem.finish_timestamp', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_timestamp', full_name='ymir.controller.TaskInfoItem.update_timestamp', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percent', full_name='ymir.controller.TaskInfoItem.percent', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_error', full_name='ymir.controller.TaskInfoItem.last_error', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2004,
  serialized_end=2281,
)


_TASKMONITORSTORAGE_TASKSENTRY = _descriptor.Descriptor(
  name='TasksEntry',
  full_name='ymir.controller.TaskMonitorStorage.TasksEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ymir.controller.TaskMonitorStorage.TasksEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ymir.controller.TaskMonitorStorage.TasksEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2369,
  serialized_end=2454,
)

_TASKMONITORSTORAGE = _descriptor.Descriptor(
  name='TaskMonitorStorage',
  full_name='ymir.controller.TaskMonitorStorage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tasks', full_name='ymir.controller.TaskMonitorStorage.tasks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TASKMONITORSTORAGE_TASKSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2284,
  serialized_end=2454,
)


_TASKMONITORSTORAGEITEM = _descriptor.Descriptor(
  name='TaskMonitorStorageItem',
  full_name='ymir.controller.TaskMonitorStorageItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='general_info', full_name='ymir.controller.TaskMonitorStorageItem.general_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitor_file_path', full_name='ymir.controller.TaskMonitorStorageItem.monitor_file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_file_path', full_name='ymir.controller.TaskMonitorStorageItem.storage_file_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repo_root', full_name='ymir.controller.TaskMonitorStorageItem.repo_root', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch_name', full_name='ymir.controller.TaskMonitorStorageItem.branch_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='ymir.controller.TaskMonitorStorageItem.request', index=5,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2457,
  serialized_end=2674,
)

_GENERALREQ.fields_by_name['req_type'].enum_type = _REQUESTTYPE
_GENERALREQ.fields_by_name['req_create_task'].message_type = _REQCREATETASK
_GENERALREQ.fields_by_name['req_get_task_info'].message_type = _REQGETTASKINFO
_GENERALRESP.fields_by_name['resp_get_task_info'].message_type = _RESPGETTASKINFO
_REQCREATETASK.fields_by_name['task_type'].enum_type = mir__common__pb2._TASKTYPE
_REQCREATETASK.fields_by_name['filter'].message_type = _TASKREQFILTER
_REQCREATETASK.fields_by_name['training'].message_type = _TASKREQTRAINING
_REQCREATETASK.fields_by_name['mining'].message_type = _TASKREQMINING
_REQCREATETASK.fields_by_name['importing'].message_type = _TASKREQIMPORTING
_REQCREATETASK.fields_by_name['exporting'].message_type = _TASKREQEXPORTING
_REQCREATETASK.fields_by_name['inference'].message_type = _TASKREQINFERENCE
_REQCREATETASK.fields_by_name['copy'].message_type = _TASKREQCOPYDATA
_TASKREQTRAINING_TRAININGDATASETTYPE.fields_by_name['dataset_type'].enum_type = mir__common__pb2._TVTTYPE
_TASKREQTRAINING_TRAININGDATASETTYPE.containing_type = _TASKREQTRAINING
_TASKREQTRAINING.fields_by_name['in_dataset_types'].message_type = _TASKREQTRAINING_TRAININGDATASETTYPE
_TASKREQEXPORTING.fields_by_name['format'].enum_type = mir__common__pb2._LABELFORMAT
_RESPGETTASKINFO_TASKINFOSENTRY.fields_by_name['value'].message_type = _TASKINFOITEM
_RESPGETTASKINFO_TASKINFOSENTRY.containing_type = _RESPGETTASKINFO
_RESPGETTASKINFO.fields_by_name['task_infos'].message_type = _RESPGETTASKINFO_TASKINFOSENTRY
_TASKINFOITEM.fields_by_name['type'].enum_type = mir__common__pb2._TASKTYPE
_TASKINFOITEM.fields_by_name['state'].enum_type = mir__common__pb2._TASKSTATE
_TASKMONITORSTORAGE_TASKSENTRY.fields_by_name['value'].message_type = _TASKMONITORSTORAGEITEM
_TASKMONITORSTORAGE_TASKSENTRY.containing_type = _TASKMONITORSTORAGE
_TASKMONITORSTORAGE.fields_by_name['tasks'].message_type = _TASKMONITORSTORAGE_TASKSENTRY
_TASKMONITORSTORAGEITEM.fields_by_name['general_info'].message_type = _TASKINFOITEM
_TASKMONITORSTORAGEITEM.fields_by_name['request'].message_type = _GENERALREQ
DESCRIPTOR.message_types_by_name['GeneralReq'] = _GENERALREQ
DESCRIPTOR.message_types_by_name['GeneralResp'] = _GENERALRESP
DESCRIPTOR.message_types_by_name['ReqCreateTask'] = _REQCREATETASK
DESCRIPTOR.message_types_by_name['TaskReqFilter'] = _TASKREQFILTER
DESCRIPTOR.message_types_by_name['TaskReqTraining'] = _TASKREQTRAINING
DESCRIPTOR.message_types_by_name['TaskReqMining'] = _TASKREQMINING
DESCRIPTOR.message_types_by_name['TaskReqImporting'] = _TASKREQIMPORTING
DESCRIPTOR.message_types_by_name['TaskReqExporting'] = _TASKREQEXPORTING
DESCRIPTOR.message_types_by_name['TaskReqInference'] = _TASKREQINFERENCE
DESCRIPTOR.message_types_by_name['TaskReqCopyData'] = _TASKREQCOPYDATA
DESCRIPTOR.message_types_by_name['ReqGetTaskInfo'] = _REQGETTASKINFO
DESCRIPTOR.message_types_by_name['RespGetTaskInfo'] = _RESPGETTASKINFO
DESCRIPTOR.message_types_by_name['TaskInfoItem'] = _TASKINFOITEM
DESCRIPTOR.message_types_by_name['TaskMonitorStorage'] = _TASKMONITORSTORAGE
DESCRIPTOR.message_types_by_name['TaskMonitorStorageItem'] = _TASKMONITORSTORAGEITEM
DESCRIPTOR.enum_types_by_name['RequestType'] = _REQUESTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GeneralReq = _reflection.GeneratedProtocolMessageType('GeneralReq', (_message.Message,), {
  'DESCRIPTOR' : _GENERALREQ,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.GeneralReq)
  })
_sym_db.RegisterMessage(GeneralReq)

GeneralResp = _reflection.GeneratedProtocolMessageType('GeneralResp', (_message.Message,), {
  'DESCRIPTOR' : _GENERALRESP,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.GeneralResp)
  })
_sym_db.RegisterMessage(GeneralResp)

ReqCreateTask = _reflection.GeneratedProtocolMessageType('ReqCreateTask', (_message.Message,), {
  'DESCRIPTOR' : _REQCREATETASK,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.ReqCreateTask)
  })
_sym_db.RegisterMessage(ReqCreateTask)

TaskReqFilter = _reflection.GeneratedProtocolMessageType('TaskReqFilter', (_message.Message,), {
  'DESCRIPTOR' : _TASKREQFILTER,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.TaskReqFilter)
  })
_sym_db.RegisterMessage(TaskReqFilter)

TaskReqTraining = _reflection.GeneratedProtocolMessageType('TaskReqTraining', (_message.Message,), {

  'TrainingDatasetType' : _reflection.GeneratedProtocolMessageType('TrainingDatasetType', (_message.Message,), {
    'DESCRIPTOR' : _TASKREQTRAINING_TRAININGDATASETTYPE,
    '__module__' : 'mir_controller_service_pb2'
    # @@protoc_insertion_point(class_scope:ymir.controller.TaskReqTraining.TrainingDatasetType)
    })
  ,
  'DESCRIPTOR' : _TASKREQTRAINING,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.TaskReqTraining)
  })
_sym_db.RegisterMessage(TaskReqTraining)
_sym_db.RegisterMessage(TaskReqTraining.TrainingDatasetType)

TaskReqMining = _reflection.GeneratedProtocolMessageType('TaskReqMining', (_message.Message,), {
  'DESCRIPTOR' : _TASKREQMINING,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.TaskReqMining)
  })
_sym_db.RegisterMessage(TaskReqMining)

TaskReqImporting = _reflection.GeneratedProtocolMessageType('TaskReqImporting', (_message.Message,), {
  'DESCRIPTOR' : _TASKREQIMPORTING,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.TaskReqImporting)
  })
_sym_db.RegisterMessage(TaskReqImporting)

TaskReqExporting = _reflection.GeneratedProtocolMessageType('TaskReqExporting', (_message.Message,), {
  'DESCRIPTOR' : _TASKREQEXPORTING,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.TaskReqExporting)
  })
_sym_db.RegisterMessage(TaskReqExporting)

TaskReqInference = _reflection.GeneratedProtocolMessageType('TaskReqInference', (_message.Message,), {
  'DESCRIPTOR' : _TASKREQINFERENCE,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.TaskReqInference)
  })
_sym_db.RegisterMessage(TaskReqInference)

TaskReqCopyData = _reflection.GeneratedProtocolMessageType('TaskReqCopyData', (_message.Message,), {
  'DESCRIPTOR' : _TASKREQCOPYDATA,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.TaskReqCopyData)
  })
_sym_db.RegisterMessage(TaskReqCopyData)

ReqGetTaskInfo = _reflection.GeneratedProtocolMessageType('ReqGetTaskInfo', (_message.Message,), {
  'DESCRIPTOR' : _REQGETTASKINFO,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.ReqGetTaskInfo)
  })
_sym_db.RegisterMessage(ReqGetTaskInfo)

RespGetTaskInfo = _reflection.GeneratedProtocolMessageType('RespGetTaskInfo', (_message.Message,), {

  'TaskInfosEntry' : _reflection.GeneratedProtocolMessageType('TaskInfosEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESPGETTASKINFO_TASKINFOSENTRY,
    '__module__' : 'mir_controller_service_pb2'
    # @@protoc_insertion_point(class_scope:ymir.controller.RespGetTaskInfo.TaskInfosEntry)
    })
  ,
  'DESCRIPTOR' : _RESPGETTASKINFO,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.RespGetTaskInfo)
  })
_sym_db.RegisterMessage(RespGetTaskInfo)
_sym_db.RegisterMessage(RespGetTaskInfo.TaskInfosEntry)

TaskInfoItem = _reflection.GeneratedProtocolMessageType('TaskInfoItem', (_message.Message,), {
  'DESCRIPTOR' : _TASKINFOITEM,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.TaskInfoItem)
  })
_sym_db.RegisterMessage(TaskInfoItem)

TaskMonitorStorage = _reflection.GeneratedProtocolMessageType('TaskMonitorStorage', (_message.Message,), {

  'TasksEntry' : _reflection.GeneratedProtocolMessageType('TasksEntry', (_message.Message,), {
    'DESCRIPTOR' : _TASKMONITORSTORAGE_TASKSENTRY,
    '__module__' : 'mir_controller_service_pb2'
    # @@protoc_insertion_point(class_scope:ymir.controller.TaskMonitorStorage.TasksEntry)
    })
  ,
  'DESCRIPTOR' : _TASKMONITORSTORAGE,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.TaskMonitorStorage)
  })
_sym_db.RegisterMessage(TaskMonitorStorage)
_sym_db.RegisterMessage(TaskMonitorStorage.TasksEntry)

TaskMonitorStorageItem = _reflection.GeneratedProtocolMessageType('TaskMonitorStorageItem', (_message.Message,), {
  'DESCRIPTOR' : _TASKMONITORSTORAGEITEM,
  '__module__' : 'mir_controller_service_pb2'
  # @@protoc_insertion_point(class_scope:ymir.controller.TaskMonitorStorageItem)
  })
_sym_db.RegisterMessage(TaskMonitorStorageItem)


_RESPGETTASKINFO_TASKINFOSENTRY._options = None
_TASKMONITORSTORAGE_TASKSENTRY._options = None

_MIR_CONTROLLER_SERVICE = _descriptor.ServiceDescriptor(
  name='mir_controller_service',
  full_name='ymir.controller.mir_controller_service',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3015,
  serialized_end=3123,
  methods=[
  _descriptor.MethodDescriptor(
    name='data_manage_request',
    full_name='ymir.controller.mir_controller_service.data_manage_request',
    index=0,
    containing_service=None,
    input_type=_GENERALREQ,
    output_type=_GENERALRESP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MIR_CONTROLLER_SERVICE)

DESCRIPTOR.services_by_name['mir_controller_service'] = _MIR_CONTROLLER_SERVICE

# @@protoc_insertion_point(module_scope)
