# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mir_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='mir_common.proto',
  package='ymir.common',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10mir_common.proto\x12\x0bymir.common*Z\n\x07TvtType\x12\x12\n\x0eTvtTypeUnknown\x10\x00\x12\x13\n\x0fTvtTypeTraining\x10\x01\x12\x15\n\x11TvtTypeValidation\x10\x02\x12\x0f\n\x0bTvtTypeTest\x10\x03*\xf1\x01\n\tAssetType\x12\x14\n\x10\x41ssetTypeUnknown\x10\x00\x12\x16\n\x12\x41ssetTypeImageJpeg\x10\x01\x12\x15\n\x11\x41ssetTypeImagePng\x10\x02\x12\x1a\n\x16\x41ssetTypeImagePixelMat\x10\x03\x12\x19\n\x15\x41ssetTypeImageYuv420p\x10\x04\x12\x1a\n\x16\x41ssetTypeImageYuv420sp\x10\x05\x12\x19\n\x15\x41ssetTypeImageYuv422p\x10\x06\x12\x1a\n\x16\x41ssetTypeImageYuv422sp\x10\x07\x12\x15\n\x11\x41ssetTypeVideoMp4\x10\x65*\xc9\x01\n\x08TaskType\x12\x13\n\x0fTaskTypeUnknown\x10\x00\x12\x14\n\x10TaskTypeTraining\x10\x01\x12\x12\n\x0eTaskTypeMining\x10\x02\x12\x11\n\rTaskTypeLabel\x10\x03\x12\x12\n\x0eTaskTypeFilter\x10\x04\x12\x16\n\x12TaskTypeImportData\x10\x05\x12\x16\n\x12TaskTypeExportData\x10\x06\x12\x14\n\x10TaskTypeCopyData\x10\x07\x12\x11\n\rTaskTypeMerge\x10\x08*\x87\x01\n\tTaskState\x12\x14\n\x10TaskStateUnknown\x10\x00\x12\x14\n\x10TaskStatePending\x10\x01\x12\x14\n\x10TaskStateRunning\x10\x02\x12\x11\n\rTaskStateDone\x10\x03\x12\x12\n\x0eTaskStateError\x10\x04\x12\x11\n\rTaskStateMiss\x10\x05*L\n\x08Sha1Type\x12\x15\n\x11SHA1_TYPE_UNKNOWN\x10\x00\x12\x13\n\x0fSHA1_TYPE_ASSET\x10\x01\x12\x14\n\x10SHA1_TYPE_COMMIT\x10\x02*\xf6\x04\n\x05RCode\x12\t\n\x05RC_OK\x10\x00\x12\x14\n\x10RC_ERROR_UNKNOWN\x10\x01\x12\x18\n\x14RC_CMD_ERROR_UNKNOWN\x10\x64\x12\x1b\n\x17RC_CMD_CORRUPT_MIR_FILE\x10\x65\x12\x1b\n\x17RC_CMD_INVALID_MIR_FILE\x10\x66\x12\x1b\n\x17RC_CMD_INVALID_MIR_REPO\x10g\x12\x17\n\x13RC_CMD_INVALID_ARGS\x10h\x12 \n\x1cRC_CMD_INVALID_BRANCH_OR_TAG\x10i\x12\x1a\n\x16RC_CMD_INVALID_COMMAND\x10j\x12\x1d\n\x19RC_CMD_MIR_FILE_NOT_FOUND\x10k\x12\x1c\n\x18RC_CMD_CONFLICTS_OCCURED\x10l\x12\x1a\n\x16RC_CMD_EMPTY_METADATAS\x10m\x12\x1a\n\x16RC_CMD_EMPTY_TRAIN_SET\x10n\x12\x18\n\x14RC_CMD_EMPTY_VAL_SET\x10o\x12\x15\n\x11RC_CMD_DIRTY_REPO\x10p\x12\x1b\n\x17RC_CMD_NOTHING_TO_MERGE\x10q\x12\x1d\n\x18RC_SERVICE_ERROR_UNKNOWN\x10\xe8\x07\x12\x1b\n\x16RC_SERVICE_INVALID_REQ\x10\xe9\x07\x12\x1c\n\x17RC_SERVICE_INVOKE_ERROR\x10\xea\x07\x12\x1f\n\x1aRC_SERVICE_UNKOWN_RESPONSE\x10\xeb\x07\x12\"\n\x1dRC_SERVICE_TASK_INVOKER_ERROR\x10\xec\x07\x12\"\n\x1dRC_SERVICE_INFO_INVOKER_ERROR\x10\xed\x07*U\n\nMirStorage\x12\x11\n\rMIR_METADATAS\x10\x00\x12\x13\n\x0fMIR_ANNOTATIONS\x10\x01\x12\x10\n\x0cMIR_KEYWORDS\x10\x02\x12\r\n\tMIR_TASKS\x10\x03*<\n\x0bLabelFormat\x12\x11\n\rNO_ANNOTATION\x10\x00\x12\x0e\n\nPASCAL_VOC\x10\x01\x12\n\n\x06IF_ARK\x10\x02\x62\x06proto3'
)

_TVTTYPE = _descriptor.EnumDescriptor(
  name='TvtType',
  full_name='ymir.common.TvtType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TvtTypeUnknown', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TvtTypeTraining', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TvtTypeValidation', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TvtTypeTest', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=33,
  serialized_end=123,
)
_sym_db.RegisterEnumDescriptor(_TVTTYPE)

TvtType = enum_type_wrapper.EnumTypeWrapper(_TVTTYPE)
_ASSETTYPE = _descriptor.EnumDescriptor(
  name='AssetType',
  full_name='ymir.common.AssetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AssetTypeUnknown', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AssetTypeImageJpeg', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AssetTypeImagePng', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AssetTypeImagePixelMat', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AssetTypeImageYuv420p', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AssetTypeImageYuv420sp', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AssetTypeImageYuv422p', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AssetTypeImageYuv422sp', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AssetTypeVideoMp4', index=8, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=126,
  serialized_end=367,
)
_sym_db.RegisterEnumDescriptor(_ASSETTYPE)

AssetType = enum_type_wrapper.EnumTypeWrapper(_ASSETTYPE)
_TASKTYPE = _descriptor.EnumDescriptor(
  name='TaskType',
  full_name='ymir.common.TaskType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TaskTypeUnknown', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskTypeTraining', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskTypeMining', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskTypeLabel', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskTypeFilter', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskTypeImportData', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskTypeExportData', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskTypeCopyData', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskTypeMerge', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=370,
  serialized_end=571,
)
_sym_db.RegisterEnumDescriptor(_TASKTYPE)

TaskType = enum_type_wrapper.EnumTypeWrapper(_TASKTYPE)
_TASKSTATE = _descriptor.EnumDescriptor(
  name='TaskState',
  full_name='ymir.common.TaskState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TaskStateUnknown', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskStatePending', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskStateRunning', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskStateDone', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskStateError', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TaskStateMiss', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=574,
  serialized_end=709,
)
_sym_db.RegisterEnumDescriptor(_TASKSTATE)

TaskState = enum_type_wrapper.EnumTypeWrapper(_TASKSTATE)
_SHA1TYPE = _descriptor.EnumDescriptor(
  name='Sha1Type',
  full_name='ymir.common.Sha1Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHA1_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA1_TYPE_ASSET', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA1_TYPE_COMMIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=711,
  serialized_end=787,
)
_sym_db.RegisterEnumDescriptor(_SHA1TYPE)

Sha1Type = enum_type_wrapper.EnumTypeWrapper(_SHA1TYPE)
_RCODE = _descriptor.EnumDescriptor(
  name='RCode',
  full_name='ymir.common.RCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RC_OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_ERROR_UNKNOWN', index=2, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_CORRUPT_MIR_FILE', index=3, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_INVALID_MIR_FILE', index=4, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_INVALID_MIR_REPO', index=5, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_INVALID_ARGS', index=6, number=104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_INVALID_BRANCH_OR_TAG', index=7, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_INVALID_COMMAND', index=8, number=106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_MIR_FILE_NOT_FOUND', index=9, number=107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_CONFLICTS_OCCURED', index=10, number=108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_EMPTY_METADATAS', index=11, number=109,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_EMPTY_TRAIN_SET', index=12, number=110,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_EMPTY_VAL_SET', index=13, number=111,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_DIRTY_REPO', index=14, number=112,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_CMD_NOTHING_TO_MERGE', index=15, number=113,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_SERVICE_ERROR_UNKNOWN', index=16, number=1000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_SERVICE_INVALID_REQ', index=17, number=1001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_SERVICE_INVOKE_ERROR', index=18, number=1002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_SERVICE_UNKOWN_RESPONSE', index=19, number=1003,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_SERVICE_TASK_INVOKER_ERROR', index=20, number=1004,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC_SERVICE_INFO_INVOKER_ERROR', index=21, number=1005,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=790,
  serialized_end=1420,
)
_sym_db.RegisterEnumDescriptor(_RCODE)

RCode = enum_type_wrapper.EnumTypeWrapper(_RCODE)
_MIRSTORAGE = _descriptor.EnumDescriptor(
  name='MirStorage',
  full_name='ymir.common.MirStorage',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MIR_METADATAS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIR_ANNOTATIONS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIR_KEYWORDS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIR_TASKS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1422,
  serialized_end=1507,
)
_sym_db.RegisterEnumDescriptor(_MIRSTORAGE)

MirStorage = enum_type_wrapper.EnumTypeWrapper(_MIRSTORAGE)
_LABELFORMAT = _descriptor.EnumDescriptor(
  name='LabelFormat',
  full_name='ymir.common.LabelFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_ANNOTATION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PASCAL_VOC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IF_ARK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1509,
  serialized_end=1569,
)
_sym_db.RegisterEnumDescriptor(_LABELFORMAT)

LabelFormat = enum_type_wrapper.EnumTypeWrapper(_LABELFORMAT)
TvtTypeUnknown = 0
TvtTypeTraining = 1
TvtTypeValidation = 2
TvtTypeTest = 3
AssetTypeUnknown = 0
AssetTypeImageJpeg = 1
AssetTypeImagePng = 2
AssetTypeImagePixelMat = 3
AssetTypeImageYuv420p = 4
AssetTypeImageYuv420sp = 5
AssetTypeImageYuv422p = 6
AssetTypeImageYuv422sp = 7
AssetTypeVideoMp4 = 101
TaskTypeUnknown = 0
TaskTypeTraining = 1
TaskTypeMining = 2
TaskTypeLabel = 3
TaskTypeFilter = 4
TaskTypeImportData = 5
TaskTypeExportData = 6
TaskTypeCopyData = 7
TaskTypeMerge = 8
TaskStateUnknown = 0
TaskStatePending = 1
TaskStateRunning = 2
TaskStateDone = 3
TaskStateError = 4
TaskStateMiss = 5
SHA1_TYPE_UNKNOWN = 0
SHA1_TYPE_ASSET = 1
SHA1_TYPE_COMMIT = 2
RC_OK = 0
RC_ERROR_UNKNOWN = 1
RC_CMD_ERROR_UNKNOWN = 100
RC_CMD_CORRUPT_MIR_FILE = 101
RC_CMD_INVALID_MIR_FILE = 102
RC_CMD_INVALID_MIR_REPO = 103
RC_CMD_INVALID_ARGS = 104
RC_CMD_INVALID_BRANCH_OR_TAG = 105
RC_CMD_INVALID_COMMAND = 106
RC_CMD_MIR_FILE_NOT_FOUND = 107
RC_CMD_CONFLICTS_OCCURED = 108
RC_CMD_EMPTY_METADATAS = 109
RC_CMD_EMPTY_TRAIN_SET = 110
RC_CMD_EMPTY_VAL_SET = 111
RC_CMD_DIRTY_REPO = 112
RC_CMD_NOTHING_TO_MERGE = 113
RC_SERVICE_ERROR_UNKNOWN = 1000
RC_SERVICE_INVALID_REQ = 1001
RC_SERVICE_INVOKE_ERROR = 1002
RC_SERVICE_UNKOWN_RESPONSE = 1003
RC_SERVICE_TASK_INVOKER_ERROR = 1004
RC_SERVICE_INFO_INVOKER_ERROR = 1005
MIR_METADATAS = 0
MIR_ANNOTATIONS = 1
MIR_KEYWORDS = 2
MIR_TASKS = 3
NO_ANNOTATION = 0
PASCAL_VOC = 1
IF_ARK = 2


DESCRIPTOR.enum_types_by_name['TvtType'] = _TVTTYPE
DESCRIPTOR.enum_types_by_name['AssetType'] = _ASSETTYPE
DESCRIPTOR.enum_types_by_name['TaskType'] = _TASKTYPE
DESCRIPTOR.enum_types_by_name['TaskState'] = _TASKSTATE
DESCRIPTOR.enum_types_by_name['Sha1Type'] = _SHA1TYPE
DESCRIPTOR.enum_types_by_name['RCode'] = _RCODE
DESCRIPTOR.enum_types_by_name['MirStorage'] = _MIRSTORAGE
DESCRIPTOR.enum_types_by_name['LabelFormat'] = _LABELFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)
